@@ -26,7 +26,8 @@ debian_add_swap <- function(droplet) {
     "fallocate -l 4G /swapfile",
     "chmod 600 /swapfile",
     "mkswap /swapfile",
-    "sudo swapon /swapfile"
+    "sudo swapon /swapfile",
+    "sudo echo \"/swapfile   none    swap    sw    0   0\" >> /etc/fstab"
   )
 }
 
