@@ -24,12 +24,13 @@
 #'   vector of key ids, or NULL, to use all keys in your account. Accounts
 #'   with the corresponding private key will be able to log in to the droplet.
 #'   See \code{\link{keys}()} for a list of the keys that you've added.
-#'   Default: NULL.
+#'   Default: NULL
 #' @param private_networking (logical) Use private networking. Private
 #'   networking is currently only available in certain regions.
 #'   Default: \code{FALSE}
 #' @param tags (character) A vector of tag names to apply to the Droplet after
 #'   it is created. Tag names can either be existing or new tags.
+#'   Default: list()
 #' @param backups (logical) Enable backups. A boolean indicating whether
 #'   automated backups should be enabled for the droplet. Automated backups can
 #'   only be enabled when the droplet is created, and cost extra.
@@ -89,7 +90,7 @@ droplet_create <- function(name = random_name(),
                         ipv6 = getOption("do_ipv6", NULL),
                         private_networking =
                           getOption("do_private_networking", NULL),
-                        tags = NULL,
+                        tags = list(),
                         user_data = NULL,
                         cloud_config = NULL,
                         wait = TRUE,
